==> bootstrap-rytmcms-1.0.19.tgz: package/templates/local/views/index.php <==
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" itemscope itemtype="http://schema.org/WebPage" lang="<?= TukiSettings::getLanguage() ?>" class="<?= $item->getHtmlClassName() ?>">
  <head>
    <?php Template::printBox("head_authorstamp"); ?>
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1">
    <script>
      document.documentElement.classList.add("index-loading");
      document.documentElement.classList.add("js");
    </script>
    <?php
    Template::addCSS("tuki.css", "css", Tuki::ENVIRONMENT_DEV);
    Template::addCSS("style.css", "dist");
    Template::addScriptBottom("bundle.js", "dist");
    Template::printBox("head_meta");
    Template::printBox("head_favicons");
    Template::printBox("head_social_media_tags");
    ?>
  </head>
  <body <?php echo Template::getBodyData(); ?> data-html-classes="<?= $item->getHtmlClassName() ?>">
    <div id="stage">
      <div id="stage-inner">
        <header>
          <?php // Template::printBox("item_view", array("id" => ID_MODULE_HEADER, "veiw" => "full")); ?>
        </header>
        <main id="c-start" class="main">
          <?php $item->printMe(); ?>
        </main>
        <footer>
          <?php // Template::printBox("item_view", array("id" => ID_MODULE_FOOTER, "veiw" => "full")); ?>
        </footer>
        <?php // Template::printBox("loading"); ?>
      </div>
    </div>
    <?php Template::printBox("footer_meta"); ?>
    <?php Template::printBox("debug", array(), P_ADMIN); ?>
  </body>
</html>

==> bootstrap-rytmcms-2.0.1.tgz: package/templates/local/views/index.php <==
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" itemscope itemtype="http://schema.org/WebPage" lang="<?= TukiSettings::getLanguage() ?>" class="<?= $item->getHtmlClassName() ?>">
  <head>
    <?php Template::printBox("head_authorstamp"); ?>
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1">
    <script>
      document.documentElement.classList.add("index-loading");
      document.documentElement.classList.add("js");
    </script>
    <?php
    Template::addCSS("tuki.css", "css", Tuki::ENVIRONMENT_DEV);
    Template::addCSS("style.css", "dist");
    Template::addScriptBottom("bundle.js", "dist");
    Template::printBox("head_meta");
    Template::printBox("head_favicons");
    Template::printBox("head_social_media_tags");
    ?>
  </head>
  <body <?php echo Template::getBodyData(); ?> data-html-classes="<?= $item->getHtmlClassName() ?>">
    <div id="stage">
      <div id="stage-inner">
        <header>
          <?php // Template::printBox("item_view", array("id" => ID_MODULE_HEADER, "view" => "full")); ?>
        </header>
        <main id="c-start" class="main">
          <?php $item->printMe(); ?>
        </main>
        <footer>
          <?php // Template::printBox("item_view", array("id" => ID_MODULE_FOOTER, "view" => "full")); ?>
        </footer>
        <?php // Template::printBox("loading"); ?>
      </div>
    </div>
    <?php Template::printBox("footer_meta"); ?>
    <?php Template::printBox("debug", array(), P_ADMIN); ?>
  </body>
</html>
